3. Command Components
=====================

This section identifies the applicable components of an OpenC2 Command.
The components of an OpenC2 Command include:

-  **Action:** List of Actions that are relevant for the CTXD. This
   Profile cannot define Actions that are not included in the OpenC2
   Language Specification, but it may extend their definitions.
-  **Target:** List of Targets included in the Language Specification
   and one Target (and its associated Specifiers) that is defined only
   for the CTXD.
-  **Arguments:** List of Command Arguments that are relevant for the
   CTXD.
-  **Actuator:** List of Actuator Specifiers that are relevant for the
   CTXD.

.. toctree::
   :maxdepth: 1

   3_1_actions
   3_2_target
   3_3_context
   3_4_command_arguments
   3_5_actuator_specifiers
